Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(833)

Unified Diff: chrome/browser/sync/test/test_http_bridge_factory.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/test_http_bridge_factory.h
diff --git a/chrome/browser/sync/test/test_http_bridge_factory.h b/chrome/browser/sync/test/test_http_bridge_factory.h
index 4c91127e7fb14b60bf1d0eb69e59796306defc42..7663677f22a700e208a139023845c179d64b761d 100644
--- a/chrome/browser/sync/test/test_http_bridge_factory.h
+++ b/chrome/browser/sync/test/test_http_bridge_factory.h
@@ -12,9 +12,9 @@
namespace browser_sync {
-class TestHttpBridge : public csync::HttpPostProviderInterface {
+class TestHttpBridge : public syncer::HttpPostProviderInterface {
public:
// Begin csync::HttpPostProviderInterface implementation:
virtual void SetExtraRequestHeaders(const char * headers) OVERRIDE {}
virtual void SetURL(const char* url, int port) OVERRIDE {}
@@ -34,17 +34,17 @@ class TestHttpBridge : public csync::HttpPostProviderInterface {
const std::string&) const OVERRIDE;
virtual void Abort() OVERRIDE;
// End csync::HttpPostProviderInterface implementation.
};
-class TestHttpBridgeFactory : public csync::HttpPostProviderFactory {
+class TestHttpBridgeFactory : public syncer::HttpPostProviderFactory {
public:
TestHttpBridgeFactory();
virtual ~TestHttpBridgeFactory();
- // csync::HttpPostProviderFactory:
- virtual csync::HttpPostProviderInterface* Create() OVERRIDE;
- virtual void Destroy(csync::HttpPostProviderInterface* http) OVERRIDE;
+ // syncer::HttpPostProviderFactory:
+ virtual syncer::HttpPostProviderInterface* Create() OVERRIDE;
+ virtual void Destroy(syncer::HttpPostProviderInterface* http) OVERRIDE;
};
} // namespace browser_sync
@@ -12,9 +12,9 @@
public:
- // Begin csync::HttpPostProviderInterface implementation:
+ // Begin syncer::HttpPostProviderInterface implementation:
virtual void SetExtraRequestHeaders(const char * headers) OVERRIDE {}
virtual void SetURL(const char* url, int port) OVERRIDE {}
@@ -34,17 +34,17 @@ class TestHttpBridge : public csync::HttpPostProviderInterface {
const std::string&) const OVERRIDE;
virtual void Abort() OVERRIDE;
- // End csync::HttpPostProviderInterface implementation.
+ // End syncer::HttpPostProviderInterface implementation.
};

Powered by Google App Engine
This is Rietveld 408576698